==> komora_service_path_plugin-1.2.7.tar.gz: komora_service_path_plugin-1.2.7/komora_service_path_plugin/forms/service_path.py <==
from django import forms
from django.db.utils import OperationalError
from netbox.forms import NetBoxModelFilterSetForm, NetBoxModelForm
from utilities.forms.fields import CommentField
from utilities.forms.rendering import FieldSet

from komora_service_path_plugin.models import ServicePath, SyncStatusChoices


class ServicePathForm(NetBoxModelForm):
    comments = CommentField(required=False, label="Comments", help_text="Comments")

    fieldsets = (FieldSet("tags", name="Misc"), )

    class Meta:
        model = ServicePath
        fields = (
            "comments",
            "tags",
        )


class ServicePathFilterForm(NetBoxModelFilterSetForm):
    model = ServicePath
    # TODO: make choices configurable (seperate model maybe)
    # WORKAROUND + TODO: Remove try/except 

    try:
        STATE_CHOICES = [("", "----")] + [
            (state, state)
            for state in ServicePath.objects.order_by("state")
            .values_list("state", flat=True)
            .distinct()
        ]
        KIND_CHOICES = [("", "----")] + [
            (kind, kind)
            for kind in ServicePath.objects.order_by("kind")
            .values_list("kind", flat=True)
            .distinct()
        ]
    except OperationalError as e:
        pass

    name = forms.CharField(required=False)
    sync_status = forms.MultipleChoiceField(
        required=False,
        choices=SyncStatusChoices,
    )
    state = forms.ChoiceField(required=False, choices=STATE_CHOICES, initial=None)
    kind = forms.ChoiceField(required=False, choices=KIND_CHOICES, initial=None)

    fieldsets = (
        FieldSet("q", "tag", "filter_id", "sync_status", name="Misc"),
        FieldSet("name", "state", "kind", name="Service Path"),
    )

==> komora_service_path_plugin-1.2.8.tar.gz: komora_service_path_plugin-1.2.8/komora_service_path_plugin/forms/service_path.py <==
from django import forms
from django.db.utils import OperationalError
from netbox.forms import NetBoxModelFilterSetForm, NetBoxModelForm
from utilities.forms.fields import CommentField
from utilities.forms.rendering import FieldSet

from komora_service_path_plugin.models import ServicePath, SyncStatusChoices


class ServicePathForm(NetBoxModelForm):
    comments = CommentField(required=False, label="Comments", help_text="Comments")

    fieldsets = (FieldSet("tags", name="Misc"), )

    class Meta:
        model = ServicePath
        fields = (
            "comments",
            "tags",
        )


class ServicePathFilterForm(NetBoxModelFilterSetForm):
    model = ServicePath
    # TODO: make choices configurable (seperate model maybe)

    STATE_CHOICES = [("", "----")]
    KIND_CHOICES = [("", "----")]

    try:
        STATE_CHOICES = STATE_CHOICES + [
            (state, state)
            for state in ServicePath.objects.order_by("state")
            .values_list("state", flat=True)
            .distinct()
        ]
        KIND_CHOICES = KIND_CHOICES + [
            (kind, kind)
            for kind in ServicePath.objects.order_by("kind")
            .values_list("kind", flat=True)
            .distinct()
        ]
    except OperationalError as e:
        pass



    name = forms.CharField(required=False)
    sync_status = forms.MultipleChoiceField(
        required=False,
        choices=SyncStatusChoices,
    )
    state = forms.ChoiceField(required=False, choices=STATE_CHOICES, initial=None)
    kind = forms.ChoiceField(required=False, choices=KIND_CHOICES, initial=None)

    fieldsets = (
        FieldSet("q", "tag", "filter_id", "sync_status", name="Misc"),
        FieldSet("name", "state", "kind", name="Service Path"),
    )
